/* libiir/src/tests/run_filter.c
 * 
 *  Copyright: ©2010, Laurence Withers.
 *  Author: Laurence Withers <l@lwithers.me.uk>
 *  License: GPLv3
*/

#include "iir.h"

#include <stdio.h>
#include <string.h>



int
main(int argc, char* argv[])
{
    FILE* outf, * inf;
    struct iir_filter_t* iir;
    double samp;

    outf = stdout;
    inf = stdin;

    /* process commandline arguments */
    if(argc == 2 && !strcmp(argv[1], "--print-summary")) {
        fputs("Runs an IIR filter on an input stream.\n", stdout);
        return 0;
    }

    switch(argc) {
    case 4:
        outf = fopen(argv[3], "w");
        if(!outf) {
            perror(argv[3]);
            return 1;
        }
        /* fall through */
    case 3:
        inf = fopen(argv[2], "r");
        if(!inf) {
            perror(argv[2]);
            return 1;
        }
        /* fall through */
    case 2:
        iir = iir_parse(argv[1]);
        if(!iir) {
            fputs("Invalid filter description string.\n", stderr);
            return 1;
        }
        break;

    default:
        fputs("Usage: run_filter 'filter desc' [infile [outfile]]\n", stdout);
        return 1;
    }

    /* run filter on our input */
    while(fscanf(inf, " %lf", &samp) == 1) {
        fprintf(outf, "%f\n", iir_filter(iir, samp));
    }

    /* clean up (for valgrind) */
    if(outf != stdout) fclose(outf);
    if(inf != stdin) fclose(inf);
    iir_filter_free(iir);

    return 0;
}



/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
